<?php
/**
 * Admin Ajax Class for Email
 *
 * @package momo-membership
 * @author MoMo Thems
 * @since v1.0.0
 */
class Mmtms_Admin_Ajax_Email {
	/**
	 * Constructor
	 */
	public function __construct() {
		$ajax_events = array(
			'mmtms_save_email_settings'    => 'mmtms_save_email_settings',
			'mmtms_generate_email_preview' => 'mmtms_generate_email_preview',
		);
		foreach ( $ajax_events as $ajax_event => $class ) {
			add_action( 'wp_ajax_' . $ajax_event, array( $this, $class ) );
			add_action( 'wp_ajax_nopriv_' . $ajax_event, array( $this, $class ) );
		}
	}

	/**
	 * Save Email Settings
	 */
	public function mmtms_save_email_settings() {
		check_ajax_referer( 'mmtms_admin_ajax_nonce', 'mmtms_nonce' );
		if ( isset( $_POST['action'] ) && 'mmtms_save_email_settings' !== $_POST['action'] ) {
			return;
		}
		$settings                                        = array();
		$settings['mmtms_email_confirmation_link']       = isset( $_POST['mmtms_email_confirmation_link'] ) ? sanitize_text_field( wp_unslash( $_POST['mmtms_email_confirmation_link'] ) ) : '';
		$settings['mmtms_email_reset_password_link']     = isset( $_POST['mmtms_email_reset_password_link'] ) ? sanitize_text_field( wp_unslash( $_POST['mmtms_email_reset_password_link'] ) ) : '';
		$settings['mmtms_email_notify_admin_new_member'] = isset( $_POST['mmtms_email_notify_admin_new_member'] ) ? sanitize_text_field( wp_unslash( $_POST['mmtms_email_notify_admin_new_member'] ) ) : '';
		$settings['mmtms_ecl_subject']                   = isset( $_POST['mmtms_ecl_subject'] ) ? sanitize_text_field( wp_unslash( $_POST['mmtms_ecl_subject'] ) ) : '';
		$settings['mmtms_ecl_body']                      = isset( $_POST['mmtms_ecl_body'] ) ? sanitize_text_field( wp_unslash( $_POST['mmtms_ecl_body'] ) ) : '';
		$settings['mmtms_sender_name']                   = isset( $_POST['mmtms_sender_name'] ) ? sanitize_text_field( wp_unslash( $_POST['mmtms_sender_name'] ) ) : '';
		$settings['mmtms_sender_email']                  = isset( $_POST['mmtms_sender_email'] ) ? sanitize_text_field( wp_unslash( $_POST['mmtms_sender_email'] ) ) : '';
		$mmtms_email_options                             = get_option( 'mmtms_email_options' );
		update_option( 'mmtms_email_options', $settings );
		echo wp_json_encode(
			array(
				'status' => 'good',
				'msg'    => esc_html__( 'Settings successfully updated.', 'momo-membership' ),
			)
		);
		exit;
	}
	/**
	 * Generate Preview Email
	 */
	public function mmtms_generate_email_preview() {
		check_ajax_referer( 'mmtms_admin_ajax_nonce', 'mmtms_nonce' );
		if ( isset( $_POST['action'] ) && 'mmtms_generate_email_preview' !== $_POST['action'] ) {
			return;
		}
		global $mmtms;
		$type = isset( $_POST['type'] ) ? sanitize_text_field( wp_unslash( $_POST['type'] ) ) : '';
		if ( empty( $type ) ) {
			return;
		}
		if ( 'verification' === $type ) {
			$args = array(
				'to'                => 'preview@mmtre.com',
				'verification_code' => '',
				'user_id'           => '',
			);
			$output = $mmtms->email->mmtms_send_email( $args, 'demo' );
		}
		echo wp_json_encode(
			array(
				'status'  => 'good',
				'content' => $output,
			)
		);
		exit;
	}
}
new Mmtms_Admin_Ajax_Email();
