<?php
/**
 * Email functions for MoMo Membership
 *
 * @package momo-membership
 * @author MoMo Themes
 * @since v1.1.1
 */
class Mmtms_Email_Helper {
	/**
	 * Constructor
	 */
	public function __construct() {
		$this->options = get_option( 'mmtms_email_options' );
	}
	/**
	 * Prepare and Send Email
	 *
	 * @param string  $email Email Address.
	 * @param string  $type Email Type.
	 * @param array   $args Arguments.
	 * @param boolean $demo Demo or Not.
	 */
	public function mmtms_prepare_and_send_email( $email, $type, $args, $demo = false ) {
		$args['to']   = $email;
		$args['type'] = $type;
		$return       = $this->mmtms_send_email( $args, $demo );
		return $return;
	}
	/**
	 * Generate Link
	 *
	 * @param array $args Link arguments.
	 */
	public function mmtms_generate_link( $args ) {
		global $mmtms;
		$mmtms_email_response_page = get_option( 'mmtms_email_response_page' );
		if ( empty( $mmtms_email_response_page ) && 'publish' !== get_post_status( $post_id ) ) {
			$mmtms_email_response_page = $this->mmtms_email_response_page();
		}
		$link   = get_permalink( $mmtms_email_response_page );
		$action = $args['action'];
		if ( 'manage' === $args['action'] ) {
			return $link . '?action=' . $action;
		}
		$email = $args['email'];
		$key   = isset( $args['key'] ) ? $args['key'] : '';
		$url   = '';
		if ( 'verify' === $action ) {
			$user_id = $args['user_id'];
			$url     = $link . '?action=' . $action . '&email=' . $email . '&user_id=' . $user_id . '&kkey=' . $key;
		} elseif ( 'reset-password' === $action ) {
			$user_login = $args['user_login'];
			$url        = $link . '?action=' . $action . '&user_login=' . rawurlencode( $user_login ) . '&key=' . $key;
		}
		return $url;
	}
	/**
	 * Crate or return email response page
	 */
	public function mmtms_email_response_page() {
		global $post, $wpdb;
		$mmtms_email_response_page = wp_cache_get( "SELECT ID FROM $wpdb->posts WHERE post_name='mmtms-email-response' AND post_status='publish'" );
		if ( empty( $mmtms_email_response_page ) ) {
			$content = '-- Please Do Not move this page under any page! -- this page is used for Membership -- / MoMo Themes ';

			return $this->mmtms_create_page(
				'mmtms-email-response',
				'mmtms_email_response_page',
				__( 'MoMo Membership', 'mmtre' ),
				$content
			);
		} else {
			return $mmtms_email_response_page;
		}
	}
	/**
	 * Create page function
	 *
	 * @param string $slug Page Slug.
	 * @param string $option Page Options ID.
	 * @param string $page_title Page Title.
	 * @param string $page_content Page Content.
	 * @param int    $post_parent Parent ID.
	 */
	public function mmtms_create_page( $slug, $option, $page_title, $page_content, $post_parent = 0 ) {
		global $wpdb;
		$page_id = get_option( $option );

		if ( $page_id > 0 ) {
			$page = get_post( $page_id );
			if ( $page && 'publish' === $page->post_status ) {
				return;
			}
		}

		$page_found = wp_cache_get( 'SELECT ID, post_status FROM ' . $wpdb->posts . ' WHERE post_name = ' . $slug . ' LIMIT 1;' );

		if ( isset( $page_found->post_status ) && 'publish' === $page_found->post_status ) {
			if ( $page_id ) {
				update_option( $option, $page_found->ID );
				return $page_found->ID;
			}
		}

		$page_data = array(
			'post_status'    => 'publish',
			'post_type'      => 'page',
			'post_author'    => 1,
			'post_name'      => $slug,
			'post_title'     => $page_title,
			'post_content'   => $page_content,
			'post_parent'    => $post_parent,
			'comment_status' => 'closed',
		);

		$page_id = wp_insert_post( $page_data );
		$res     = update_option( $option, $page_id );
		return $page_id;
	}
	/**
	 * Send Email
	 *
	 * @param string $args Arguments.
	 * @param string $demo Demo or Not.
	 */
	public function mmtms_send_email( $args, $demo ) {
		global $mmtms;
		$default = array(
			'to'   => '',
			'type' => 'verification',
			'demo' => $demo,
			'user' => esc_html__( 'preview_user', 'momo-membership' ),
		);
		$args    = array_merge( $default, $args );

		switch ( $args['type'] ) {
			case 'verification':
				$link    = $this->mmtms_generate_link(
					array(
						'email'   => rawurlencode( $args['to'] ),
						'action'  => 'verify',
						'user_id' => $args['user_id'],
						'key'     => $args['verification_code'],
					)
				);
				$subject = ( ! empty( $this->options['mmtms_ecl_subject'] ) )
					?
						$this->options['mmtms_ecl_subject']
					:
						__( 'Verify your subscription', 'mmtms' );
				$file    = 'mmtms-email-body';

				$args['message'] = isset( $this->options['mmtms_ecl_body'] ) ? $this->options['mmtms_ecl_body'] : '';
				$args['message'] = str_replace( '{username}', $args['user'], $args['message'] );
				$link            = '<a href="' . esc_url( $link ) . '" style="
									background: #5454ed;
									color: #fff;
									padding: 4px 14px;
									text-decoration: none;
									border-radius: 8px;
									display:inline-block;
									margin: 0 10px;
									">' . esc_html__( 'Click Here', 'momo-membership' ) . '</a>';
				$args['message'] = str_replace( '{confirmation_link}', $link, $args['message'] );
				break;
			case 'verified':
				break;
			case 'password_reset':
				$link    = $this->mmtms_generate_link(
					array(
						'email'      => rawurlencode( $args['to'] ),
						'action'     => 'reset-password',
						'user_login' => $args['user_login'],
						'key'        => $args['key'],
					)
				);
				$subject = ( ! empty( $this->options['mmtms_email_verification_subject'] ) )
					?
						$this->options['mmtms_email_verification_subject']
					:
						__( 'Reset your password', 'mmtms' );
				$file    = 'mmtms-password-reset';

				$args['link'] = $link;
				break;
		}

		if ( empty( $args['to'] ) ) {
			return;
		}
		$args['subject'] = $subject;

		$email_message = array(
			'to'      => $args['to'],
			'subject' => $subject,
			'message' => stripslashes( $this->mmtms_email_from_template( $file, $args ) ),
			'from'    => $this->mmtms_get_from_info(),
			'type'    => $args['type'],
			'html'    => 'yes',
		);
		if ( 'demo' === $demo ) {
			return $email_message;
		} else {
			return $this->mmtms_deliver_email( $email_message );
		}
	}
	/**
	 * Deliver Email
	 *
	 * @param array $email_message Email Message.
	 */
	public function mmtms_deliver_email( $email_message ) {
		if ( 'yes' === $email_message['html'] ) {
			add_filter( 'wp_mail_content_type', array( $this, 'mmtms_set_html_content_type' ) );
		}
		$headers   = array();
		$headers[] = 'From: ' . $email_message['from'];
		$return    = wp_mail( $email_message['to'], $email_message['subject'], $email_message['message'], $headers );

		if ( 'yes' === $email_message['html'] ) {
			remove_filter( 'wp_mail_content_type', array( $this, 'mmtms_set_html_content_type' ) );
		}

		$ts_mail_errors = array();
		if ( ! $return ) {
			global $ts_mail_errors;
			global $phpmailer;
			if ( ! isset( $ts_mail_errors ) ) {
				$ts_mail_errors = array();
			}

			if ( isset( $phpmailer ) ) {
				$ts_mail_errors[] = $phpmailer->ErrorInfo;
			}
			return array(
				'status' => 'bad',
				'result' => $return,
				'error'  => $ts_mail_errors,
			);
		} else {
			return array(
				'status' => 'good',
				'result' => $return,
			);
		}
	}
	/**
	 * Set HTML Content Type
	 */
	public function mmtms_set_html_content_type() {
		return 'text/html';
	}
	/**
	 * Get From Info
	 */
	public function mmtms_get_from_info() {
		$site_name   = get_bloginfo( 'name' );
		$admin_email = get_option( 'admin_email' );
		$from_name   = isset( $this->options['mmtms_sender_name'] ) && ! empty( $this->options['mmtms_sender_name'] )
			?
			$this->options['mmtms_sender_name']
			:
			$site_name;
		$from_email  = isset( $this->options['mmtms_sender_email'] ) && ! empty( $this->options['mmtms_sender_email'] )
			?
			$this->options['mmtms_sender_email']
			:
			$admin_email;
		return $from_name . ' <' . $from_email . '>';
	}
	/**
	 * Generate email from template
	 *
	 * @param string $file Template file name.
	 * @param array  $args Email Arguments.
	 */
	public function mmtms_email_from_template( $file, $args ) {
		global $tecsb;
		$link        = isset( $args['link'] ) && ! empty( $args['link'] ) ? $args['link'] : '';
		$message     = isset( $args['message'] ) && ! empty( $args['message'] ) ? $args['message'] : '';
		$email       = $args['to'];
		$email_title = $args['subject'];
		ob_start();
		$header   = $this->mmtms_template_loader( 'mmtms-email-header' );
		$footer   = $this->mmtms_template_loader( 'mmtms-email-footer' );
		$template = $this->mmtms_template_loader( $file );
		include_once $header;
		include_once $template;
		include_once $footer;
		return ob_get_clean();
	}
	/**
	 * Email Template Loader
	 *
	 * @param string $filename Filename.
	 */
	public function mmtms_template_loader( $filename ) {
		global $mmtms;
		$filename = $filename . '.php';
		$template = $mmtms->plugin_path . '/email/' . $filename;
		return $template;
	}
	/**
	 * Generate Email Content
	 *
	 * @param string $case Condition.
	 */
	public function mmtms_get_email_content( $case ) {
		switch ( $case ) {
			case 'site_link':
				return get_site_url();
			case 'site_brand':
				if ( get_header_image() ) :
					ob_start();
					?>
					<img src="<?php header_image(); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
					<?php
					return ob_get_clean();
				else :
					ob_start()
					?>
					<?php bloginfo( 'name' ); ?>
					<?php
					return ob_get_clean();
				endif;
				return;
			case 'default':
				return;
		}
	}
}
