<?php
/**
 * MMTMS User Registration
 *
 * @package momo-membership
 * @author MoMo Themes
 */
class Mmtms_User_Profile {
	/**
	 * Constructor
	 */
	public function __construct() {
		global $mmtms;
		$this->email_options = get_option( 'mmtms_email_options' );
		$yesno               = $this->get_settings_by_key( 'email', 'mmtms_email_confirmation_link' );
		add_action( 'user_register', array( $this, 'mmtms_check_and_add_unverified_status_to_new_user' ), 10, 2 );
		if ( 'on' === $yesno ) {
			add_filter( 'manage_users_columns', array( $this, 'mmtms_add_verification_status_column' ) );
			add_filter( 'manage_users_custom_column', array( $this, 'mmtms_add_verification_status_info' ), 10, 3 );

			add_action( 'wp_authenticate_user', array( $this, 'mmtms_check_user_validation_status' ), 10, 2 );
		}

		$notify = isset( $this->email_options['mmtms_email_notify_admin_new_member'] ) ? $this->email_options['mmtms_email_notify_admin_new_member'] : '';
		if ( 'on' === $notify ) {
			add_action( 'register_new_user', 'wp_send_new_user_notifications' );
			add_action( 'edit_user_created_user', 'wp_send_new_user_notifications', 10, 2 );
		} else {
			remove_action( 'register_new_user', 'wp_send_new_user_notifications' );
			remove_action( 'edit_user_created_user', 'wp_send_new_user_notifications', 10, 2 );
		}
	}

	/**
	 * Check if email verified
	 *
	 * @param WP_User $user WP_User.
	 * @param string  $password Password.
	 */
	public function mmtms_check_user_validation_status( $user, $password ) {
		global $mmtms;
		$user_id = $user->ID;
		if ( ! $mmtms->helper->check_user_is_verified( $user_id ) ) {
			$errors = new WP_Error();
			$errors->add( 'authentication_failed', __( '<strong>ERROR</strong>: This account has not been verified. Please check your email and verify your account.', 'momo-membership' ) );
			return $errors;
		}
		return $user;
	}
	/**
	 * Add unverified status to newly added user
	 *
	 * @param integer $user_id User ID.
	 * @param array   $userdata User Data.
	 */
	public function mmtms_check_and_add_unverified_status_to_new_user( $user_id, $userdata ) {
		$yesno = $this->get_settings_by_key( 'email', 'mmtms_email_confirmation_link' );
		if ( 'on' === $yesno ) {
			$this->mmtms_add_activation_send_email( $userdata, $user_id );
		}
	}
	/**
	 * Add verification status and send email
	 *
	 * @param array   $userdata Userdata.
	 * @param integer $user_id User ID.
	 */
	public function mmtms_add_activation_send_email( $userdata, $user_id ) {
		global $mmtms;
		$email             = $userdata['user_email'];
		$verification_code = $mmtms->helper->mmtms_generate_unique_key( $email );
		update_post_meta( $user_id, '_mmtms_verification_status', 'unverified' );
		update_post_meta( $user_id, '_mmtms_verification_code', $verification_code );
		$args = array(
			'verification_code' => $verification_code,
			'user_id'           => $user_id,
		);
		$mmtms->email->mmtms_prepare_and_send_email( $email, 'verification', $args );
	}
	/**
	 * Add Verification status column
	 *
	 * @param array $columns Default columns.
	 */
	public function mmtms_add_verification_status_column( $columns ) {
		$columns['verification_status'] = esc_html__( 'Verification Status', 'momo-membership' );
		return $columns;
	}
	/**
	 * Add verificaiton status info to column
	 *
	 * @param string  $output Output.
	 * @param string  $column_name Column Name.
	 * @param integer $user_id User ID.
	 */
	public function mmtms_add_verification_status_info( $output, $column_name, $user_id ) {
		global $mmtms;
		switch ( $column_name ) {
			case 'verification_status':
				$status  = $mmtms->helper->get_user_verification_status( $user_id );
				$output .= '<span class="mmtms-user-vstatus ' . $status . '">' . $status . '</span>';
				break;
		}
		return $output;
	}
	/**
	 * Get ssettings by key
	 *
	 * @param string $key Key.
	 * @param string $type Type of settings.
	 */
	public function get_settings_by_key( $key, $type ) {
		if ( 'email' === $key ) {
			return isset( $this->email_options[ $type ] ) ? $this->email_options[ $type ] : '';
		}
		return null;
	}
}
new Mmtms_User_Profile();
