<?php
/**
 * MoMo Themes Membership Activity Ajax
 *
 * @since 1.1.0
 * @author MoMo Themes
 * @package momo-membership
 */
class Mmt_Members_Activity_Ajax {
	/**
	 * Constructor
	 */
	public function __construct() {
		$ajax_events = array(
			'mmt_member_generate_activity_list' => 'mmt_member_generate_activity_list',
		);
		foreach ( $ajax_events as $ajax_event => $class ) {
			add_action( 'wp_ajax_' . $ajax_event, array( $this, $class ) );
			add_action( 'wp_ajax_nopriv_' . $ajax_event, array( $this, $class ) );
		}
	}
	/**
	 * Generate Activity list of member
	 */
	public function mmt_member_generate_activity_list() {
		check_ajax_referer( 'mmtms_admin_ajax_nonce', 'mmtms_nonce' );
		if ( isset( $_POST['action'] ) && 'mmt_member_generate_activity_list' !== $_POST['action'] ) {
			return;
		}
		$member_id = isset( $_POST['member_id'] ) ? sanitize_text_field( wp_unslash( $_POST['member_id'] ) ) : 0;
		$index     = isset( $_POST['index'] ) ? sanitize_text_field( wp_unslash( $_POST['index'] ) ) : 0;
		$direction = isset( $_POST['direction'] ) ? sanitize_text_field( wp_unslash( $_POST['direction'] ) ) : 'none';
		$username  = isset( $_POST['username'] ) ? sanitize_text_field( wp_unslash( $_POST['username'] ) ) : '';
		
		if ( 0 === $member_id ) {
			return;
		}
		$page         = $index + 1;
		$kw_per_page  = 2;
		$start        = ( $page - 1 ) * $kw_per_page;
		$end          = $kw_per_page * $page;
		$madgen       = new Mmt_Members_Generate_Data( $member_id );
		$session_list = $madgen->mmt_generate_member_session_list( $start, $end );
		$total        = $madgen->mmt_get_total_session_count();
		if ( empty( $session_list ) ) {
			echo wp_json_encode(
				array(
					'status' => 'bad',
					'title'  => esc_html__( 'Member - ', 'momo-membership' ) . $username,
					'msg'    => esc_html__( 'Activity record not found.', 'momo-membership' ),
				)
			);
			exit;
		}
		if ( is_array( $session_list ) && ! empty( $session_list ) ) {
			$visit_content = $this->mmt_generate_list_from_session_list( $session_list, 'visit', $madgen );
			$pagination    = $this->mmt_generate_pagination( $page, $total, 'sesions' );
			$container     = '<div class="session_list_container_lb" data-index=' . $index . ' data-username="' . $username . '" data-userid="' . $member_id . '">';
			$container    .= $visit_content . $pagination;
			$container    .= '</div>';
			echo wp_json_encode(
				array(
					'status'  => 'good',
					'title'   => esc_html__( 'Member - ', 'momo-membership' ) . $username,
					'content' => $container,
				)
			);
			exit;
		}
	}
	/**
	 * Generate list from session list
	 *
	 * @param array                     $session_list Sessions List.
	 * @param string                    $type List type.
	 * @param Mmt_Members_Generate_Data $madgen Generator.
	 */
	public function mmt_generate_list_from_session_list( $session_list, $type, $madgen ) {
		ob_start();
		if ( 'visit' === $type ) {
			?>
			<span class="mmt_ap_lb_title">
				<i class="mmtms-icon-eye"></i><?php esc_html_e( 'Post / Page visited', 'momo-membership' ); ?>
			</span>
			<ul class="mmt_aplb_session">
			<?php
			foreach ( $session_list as $session ) :
				$member_id   = $session->member_id;
				$session_key = $session->session_key;
				?>
				<li class="session_list">
					<span class="mmt_aplb_sl_title">
					<strong><?php esc_html_e( 'Session Datetime', 'momo-membership' ); ?></strong> - <?php echo esc_html( $session->login_time ); ?>
					</span>
					<?php
					$pplist = $madgen->mmt_generate_pplist_from_session_key( $session_key, $type );
					if ( empty( $pplist ) ) {
						?>
						<span class="mmt_aplb_empty_session">
							<?php esc_html_e( 'Activity not found.', 'momo-membership' ); ?>
						</span>
						<?php
					} else {
						$wp_posts_string = $pplist->wp_posts;
						$wp_posts        = explode( ',', $wp_posts_string );
						if ( empty( $wp_posts ) ) {
							?>
							<span class="mmt_aplb_empty_session">
								<?php esc_html_e( 'Activity not found.', 'momo-membership' ); ?>
							</span>
							<?php
						} else {
							?>
							<ul class="mmt_aplb_post_title_list">
							<?php
							foreach ( $wp_posts as $post_id ) {
								?>
								<li>
									<a href="<?php echo esc_url( get_the_permalink( $post_id ) ); ?>" >
										<?php echo esc_html( get_the_title( $post_id ) ); ?>
									</a>
								</li>
								<?php
							}
							?>
							</ul>
							<?php
						}
					}
					?>
				</li>
				<?php
			endforeach;
			?>
			</ul>
			<?php
		}
		return ob_get_clean();
	}
	/**
	 * Generate Pagination
	 *
	 * @param int    $page Pages.
	 * @param int    $total Total Count.
	 * @param string $type Type of pagination.
	 */
	public function mmt_generate_pagination( $page, $total, $type = 'sessions' ) {
		ob_start();
		?>
		<div class="mmt-card-left" data-total=<?php echo esc_html( $total ); ?>>
			<span class="mmt-range-lr" data-sym="-"><i class="mmtms-icon-angle-left"></i></span>
			<span class="mmt-range-pn"><?php echo esc_html( $page ); ?></span>
			<span class="mmt-range-lr" data-sym="+"><i class="mmtms-icon-angle-right"></i></span>
		</div>

		<?php
		return ob_get_clean();
	}
}
new Mmt_Members_Activity_Ajax();
