<?php
/**
 * MoMo Membership - Members Activity Data Store
 *
 * @since 1.1.0
 * @author MoMo Themes
 * @package momo-membership
 */
class Mmt_Members_Data {
	/**
	 * Members table
	 *
	 * @var string
	 */
	private $members_table = 'mmtms_members';
	/**
	 * Members Activity Table
	 *
	 * @var string
	 */
	private $activity_table = 'mmtms_member_activities';
	/**
	 * Member session table
	 *
	 * @var string
	 */
	private $session_table = 'mmtms_member_session_time';
	/**
	 * Member ID
	 *
	 * @var integer
	 */
	private $member_id;
	/**
	 * Visit Tracking to check double post
	 *
	 * @var boolean
	 */
	private $visit_counter = false;
	/**
	 * Constructor
	 */
	public function __construct() {
		add_action( 'set_current_user', array( $this, 'mmt_member_activity_login_data' ) );
		add_action( 'clear_auth_cookie', array( $this, 'mmt_member_activity_logout_data' ) );

		add_action( 'template_redirect', array( $this, 'mmt_member_activity_record' ) );
		$this->member_id = get_current_user_id();
	}
	/**
	 * When user logs in
	 */
	public function mmt_member_activity_login_data() {
		$this->member_id = get_current_user_id();
		if ( 0 === $this->member_id ) {
			return;
		}
		$member_recorded = $this->mmt_check_member_exist();
		update_user_meta( $this->member_id, '_mmtms_last_login', time() );
		if ( $member_recorded ) {
			$this->mmt_update_member_record();
		} else {
			$this->mmt_insert_member_record();
		}
		$this->mmt_insert_update_session_time( 'login' );
	}
	/**
	 * When user logs out
	 *
	 * @param string $user_id User ID.
	 */
	public function mmt_member_activity_logout_data( $user_id ) {
		$this->mmt_insert_update_session_time( 'logout' );
	}
	/**
	 * Get Session Token
	 */
	public function mmt_member_get_session_token() {
		require_once ABSPATH . 'wp-includes/pluggable.php';
		return wp_get_session_token();
	}
	/**
	 * Check member stored to mmtms_members table
	 */
	protected function mmt_check_member_exist() {
		global $wpdb;
		$table = $wpdb->prefix . $this->members_table;
		$row = $wpdb->get_row(
			$wpdb->prepare(
				"SELECT * FROM
				$table
				WHERE member_id = %d",
				$this->member_id
			)
		);

		return ! empty( $row );
	}
	/**
	 * Update mmtms_members Record
	 */
	protected function mmt_update_member_record() {
		global $wpdb;
		$session_key   = $this->mmt_get_recorded_session_key();
		$session_count = $this->mmt_get_recorded_session_count();
		$session_count = $session_key === $this->mmt_member_get_session_token() ? $session_count : $session_count + 1;
		$data = array(
			'last_seen'      => gmdate( 'Y-m-d H:i:s', time() ),
			'last_session'   => $this->mmt_member_get_session_token(),
			'sessions_count' => $session_count,
		);
		$res = $wpdb->update(
			$wpdb->prefix . $this->members_table,
			$data,
			array(
				'member_id' => $this->member_id,
			)
		);
	}
	/**
	 * Insert mmtms_members Record
	 */
	protected function mmt_insert_member_record() {
		global $wpdb;
		$data = array(
			'member_id'      => $this->member_id,
			'last_seen'      => gmdate( 'Y-m-d H:i:s', time() ),
			'last_session'   => $this->mmt_member_get_session_token(),
			'sessions_count' => 1,
		);
		$res = $wpdb->insert( $wpdb->prefix . $this->members_table, $data );
	}
	/**
	 * Retrieves recorded session key
	 */
	protected function mmt_get_recorded_session_key() {
		global $wpdb;
		$table = $wpdb->prefix . $this->members_table;
		$row = $wpdb->get_row(
			$wpdb->prepare(
				"SELECT last_session FROM
				$table
				WHERE member_id = %d",
				$this->member_id
			)
		);

		return ! empty( $row ) ? $row->last_session : false;
	}
	/**
	 * Retrieves recorded session key
	 */
	protected function mmt_get_recorded_session_count() {
		global $wpdb;
		$table = $wpdb->prefix . $this->members_table;
		$row = $wpdb->get_row(
			$wpdb->prepare(
				"SELECT sessions_count FROM
				$table
				WHERE member_id = %d",
				$this->member_id
			)
		);

		return ! empty( $row ) ? $row->sessions_count : false;
	}
	/**
	 * Insert Update Session Time
	 *
	 * @param string $type Login or logout.
	 */
	protected function mmt_insert_update_session_time( $type ) {
		global $wpdb;
		if ( 'login' === $type ) {
			$session_key = $this->mmt_member_get_session_token();
			$data = array(
				'member_id'   => $this->member_id,
				'session_key' => $session_key,
				'login_time'  => gmdate( 'Y-m-d H:i:s', time() ),
			);
			if ( ! $this->mmt_check_session_key_in_session_time( $session_key ) ) {
				$res = $wpdb->insert( $wpdb->prefix . $this->session_table, $data );
			}
		} elseif ( 'logout' === $type ) {
			$session_key = $this->mmt_member_get_session_token();
			if ( $this->mmt_check_session_key_in_session_time( $session_key ) ) {
				$data = array(
					'logout_time' => gmdate( 'Y-m-d H:i:s', time() ),
				);
				$res = $wpdb->update(
					$wpdb->prefix . $this->session_table,
					$data,
					array(
						'member_id'   => $this->member_id,
						'session_key' => $session_key,
					)
				);
			}
		}
	}
	/**
	 * Check session key in session time
	 *
	 * @param string $session_key Session key.
	 */
	protected function mmt_check_session_key_in_session_time( $session_key ) {
		global $wpdb;
		$table = $wpdb->prefix . $this->session_table;
		$row   = wp_cache_get( 'mmt_ma_check_sk_in_st' );
		if ( false === $row ) {
			$row = $wpdb->get_row(
				$wpdb->prepare(
					"SELECT * FROM
					$table
					WHERE member_id = %d AND session_key = %s",
					$this->member_id,
					$session_key
				)
			);
			wp_cache_set( 'mmt_ma_check_sk_in_st', $row );
		}

		return ! empty( $row ) ? true : false;
	}
	/**
	 * Records member activity
	 */
	public function mmt_member_activity_record() {
		if ( ! is_user_logged_in() ) {
			return;
		}

		$this->member = wp_get_current_user();
		$wp_post_id   = $this->mmt_get_wp_post_id();
		if ( $wp_post_id ) {
			$this->mmt_record_user_visit_activity( $wp_post_id );
		}
	}
	/**
	 * Gets current post ID.
	 */
	protected function mmt_get_wp_post_id() {
		global $post;
		$wp_post_id = null;
		if ( is_singular() ) {
			$wp_post_id = $post->ID;
		} elseif ( is_home() ) {
			$page_id = intval( get_option( 'page_for_posts' ) );
			if ( $page_id ) {
				$wp_post_id = $page_id;
			}
		}
		return $wp_post_id;
	}
	/**
	 * Record user 'visit' activity
	 *
	 * @param integer $wp_post_id Post ID.
	 */
	protected function mmt_record_user_visit_activity( $wp_post_id ) {
		global $wpdb;
		$recorded_posts = $this->mmt_get_user_visited_current_session();
		$session_key = $this->mmt_member_get_session_token();
		if ( ! empty( $recorded_posts ) ) {
			$wp_posts = $recorded_posts . ',' . $wp_post_id;
			$data     = array(
				'wp_posts' => $wp_posts,
			);
			$res      = wp_cache_get( 'mmt_ma_record_user_visit_activity' );
			if ( false === $res ) {
				$res = $wpdb->update(
					$wpdb->prefix . $this->activity_table,
					$data,
					array(
						'member_id'     => $this->member_id,
						'session_key'   => $session_key,
						'activity_type' => 'visit',
					)
				);
				wp_cache_set( 'mmt_ma_record_user_visit_activity', $res );
			}
		} else {
			$wp_posts = $wp_post_id;
			$data     = array(
				'member_id'     => $this->member_id,
				'session_key'   => $session_key,
				'activity_type' => 'visit',
				'wp_posts'      => $wp_posts,
			);
			$res      = $wpdb->insert( $wpdb->prefix . $this->activity_table, $data );
		}
	}
	/**
	 * Get current visited pages on current sessions
	 */
	protected function mmt_get_user_visited_current_session() {
		global $wpdb;
		$table       = $wpdb->prefix . $this->activity_table;
		$session_key = $this->mmt_member_get_session_token();
		$wp_posts    = wp_cache_get( 'mmt_ma_user_visited_current_session' );
		if ( false === $wp_posts ) {
			$wp_posts = $wpdb->get_row(
				$wpdb->prepare(
					"SELECT * FROM
					$table
					WHERE member_id = %d AND session_key = %s AND activity_type='visit'",
					$this->member_id,
					$session_key
				)
			);
			wp_cache_set( 'mmt_ma_user_visited_current_session', $wp_posts );
		}
		return ! empty( $wp_posts ) ? $wp_posts->wp_posts : false;
	}
}
new Mmt_Members_Data();
