<?php
/**
 * MoMo Membership - Members Activity Database
 *
 * @since 1.1.0
 * @author MoMo Themes
 * @package momo-membership
 */
class Mmt_Members_Database {
	/**
	 * Table names
	 *
	 * @var array
	 */
	private $tables;
	/**
	 * Option Name
	 *
	 * @var string
	 */
	private $db_option_name = 'mmt_activity_db_version';
	/**
	 * Constructor
	 */
	public function __construct() {
		define( 'MMT_ACTIVITY_DB_VERSION', '1.0' );
		$this->tables = array(
			'mmtms_members',
			'mmtms_member_activities',
			'mmtms_member_session_time',
		);
		add_action( 'plugins_loaded', array( $this, 'mmt_update_install_member_activity_dababase' ) );

		register_activation_hook( MMTMS_FILE, array( $this, 'momo_membership_plugin_activate' ) );
		register_deactivation_hook( MMTMS_FILE, array( $this, 'momo_membership_plugin_deactivate' ) );
	}
	/**
	 * Plugin activate
	 */
	public function momo_membership_plugin_activate() {
		global $wpdb;

		$this->momo_membership_install_activity_db();
	}
	/**
	 * Plugin Deactivate
	 */
	public function momo_membership_plugin_deactivate() {
		do_action( 'momo_membership_deactivation' );
	}
	/**
	 * Install update database
	 */
	public function mmt_update_install_member_activity_dababase() {
		if ( get_site_option( MMT_ACTIVITY_DB_VERSION ) !== $this->db_option_name ) {
			$this->momo_membership_install_activity_db();
		}
	}
	/**
	 * Update database version
	 */
	public function mmt_activity_update_version() {
		$current_version = get_option( $this->db_option_name );
		update_option( $this->db_option_name, MMT_ACTIVITY_DB_VERSION );
	}
	/**
	 * Install MMT Activity database
	 */
	public function momo_membership_install_activity_db() {
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();
		require_once ABSPATH . 'wp-admin/includes/upgrade.php';

		foreach ( $this->tables as $table_name ) :
			if ( 'mmtms_members' === $table_name ) {
				$wp_table_name = $wpdb->prefix . $table_name;
				$table_query   = "CREATE TABLE $wp_table_name (
					mmtms_members_id bigint(20) unsigned NOT NULL auto_increment,
					member_id bigint(20) unsigned NOT NULL default '0',
					last_seen datetime,
					sessions_count bigint(20),
					last_session varchar(255),
					PRIMARY KEY  (mmtms_members_id),
					UNIQUE KEY member_id (member_id),
					KEY last_seen (last_seen)
					) $charset_collate;";

				dbDelta( $table_query );
			}
			if ( 'mmtms_member_activities' === $table_name ) {
				$wp_table_name = $wpdb->prefix . $table_name;
				$table_query   = "CREATE TABLE $wp_table_name (
					activity_id bigint(20) unsigned NOT NULL auto_increment,
					member_id bigint(20) unsigned NOT NULL,
					activity_type varchar(20) NOT NULL,
					wp_posts longtext NOT NULL,
					session_key varchar(255) NOT NULL DEFAULT '',
					PRIMARY KEY  (activity_id),
					KEY member_session_activity (member_id, session_key, activity_type)
					) $charset_collate;";

				dbDelta( $table_query );
			}
			if ( 'mmtms_member_session_time' === $table_name ) {
				$wp_table_name = $wpdb->prefix . $table_name;
				$table_query   = "CREATE TABLE $wp_table_name (
					session_time_id bigint(20) unsigned NOT NULL auto_increment,
					member_id bigint(20) unsigned NOT NULL default '0',
					session_key varchar(255) NOT NULL,
					login_time datetime,
					logout_time datetime,
					PRIMARY KEY  (session_time_id),
					KEY member_session (member_id, session_key)
					) $charset_collate;";

				dbDelta( $table_query );
			}
		endforeach;
		$this->mmt_activity_update_version();
	}
}
new Mmt_Members_Database();
